==> igloo_0_1_6.zip: igloo_0_1_6/igloo/language/1/barnraiser_01/pol_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');

//HEADER
$lang['hdr_polls'] = 							"polls";
$lang['hdr_poll'] = 							"poll";
$lang['hdr_vote_history'] =						"vote history";
$lang['hdr_my_vote_history'] =					"my vote history";
$lang['hdr_forthcoming_polls'] = 				"forthcoming polls";
$lang['hdr_archive_polls'] = 					"archive polls";
$lang['hdr_my_network_polls'] = 				"latest polls from my network";
$lang['hdr_options'] =							"poll options";
$lang['hdr_poll_author'] = 						"author";



//SUBMIT
$lang['sub_vote'] = 							"vote";
$lang['sub_vote_change'] = 						"change vote";

//HREF
$lang['href_network_poll'] = 					"view their polls";
$lang['href_view_node'] = 						"latest from the group";
$lang['href_view_network'] = 					"latest from my network";
$lang['href_my_polls'] = 						"my polls";
$lang['href_marked'] = 							"marked polls";
$lang['href_add_poll'] = 						"add a poll to my polls";
$lang['href_voted'] = 							"polls i've voted in";
$lang['href_list_polls'] = 						"list polls for this author";


// ERR
$lang['err_no_polls'] = 						"Sorry, there are no polls available.";


//BODY TEXT
$lang['txt_end'] = 								"end";
$lang['txt_anonymous'] =						"anonymous";
$lang['txt_start'] = 							"start";
$lang['txt_question'] =							"question";
$lang['txt_required'] =							"required";
$lang['txt_poll_required'] =					"you are required to vote before seeing comments.";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_tag'] = 								"tags";
$lang['txt_options'] = 							"options";
$lang['txt_view'] = 							"view";
$lang['txt_group_link'] = 						"This poll is from the group";
$lang['txt_intro_group'] = 						"Listed are the last MAXLISTNUMBER (max) polls that have been published by the groups that you are a member of.";
$lang['txt_intro_node'] = 						"Listed are the last MAXLISTNUMBER (max) polls that have been published by a member of this community.";
$lang['txt_intro_network'] = 					"Listed are the last MAXLISTNUMBER (max) polls that have been published by a person in your network.";
$lang['txt_outro_group'] = 						"The following groups have not published a polls within the last MAXLISTNUMBER.";
$lang['txt_outro_network'] = 					"The following people in your network have not published a poll within the last MAXLISTNUMBER.";
$lang['txt_intro_voted'] = 						"The following polls are polls that have received your vote.";
$lang['txt_poll'] = 							"poll"; //breadcrumb


?>

==> igloo_0_1_8.zip: igloo_0_1_8/igloo/language/1/barnraiser_01/pol_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_polls'] = 							"polls";
$lang['hdr_poll'] = 							"poll";
$lang['hdr_vote_history'] =						"vote history";
$lang['hdr_my_vote_history'] =					"my vote history";
$lang['hdr_forthcoming_polls'] = 				"forthcoming polls";
$lang['hdr_archive_polls'] = 					"archive polls";
$lang['hdr_my_network_polls'] = 				"latest polls from my network";
$lang['hdr_options'] =							"poll options";
$lang['hdr_poll_author'] = 						"author";


//SUBMIT
$lang['sub_vote'] = 							"vote";
$lang['sub_vote_change'] = 						"change vote";


//HREF
$lang['href_network_poll'] = 					"view their polls";
$lang['href_view_node'] = 						"latest from the group";
$lang['href_view_network'] = 					"latest from my network";
$lang['href_my_polls'] = 						"my polls";
$lang['href_marked'] = 							"marked polls";
$lang['href_add_poll'] = 						"add a poll to my polls";
$lang['href_voted'] = 							"polls i've voted in";
$lang['href_list_polls'] = 						"list polls for this author";


// ERR
$lang['err_no_polls'] = 						"Sorry, there are no polls available.";


//BODY TEXT
$lang['txt_end'] = 								"end";
$lang['txt_anonymous'] =						"anonymous";
$lang['txt_start'] = 							"start";
$lang['txt_question'] =							"question";
$lang['txt_required'] =							"required";
$lang['txt_poll_required'] =					"you are required to vote before seeing comments.";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_tag'] = 								"tags";
$lang['txt_options'] = 							"options";
$lang['txt_view'] = 							"view";
$lang['txt_intro_node'] = 						"Listed are the last SYS_KEYWORD_NUMBER (max) polls that have been published by a member of this community.";
$lang['txt_intro_network'] = 					"Listed are the last SYS_KEYWORD_NUMBER (max) polls that have been published by a person in your network.";
$lang['txt_outro_network'] = 					"The following people in your network have not published a poll within the last SYS_KEYWORD_NUMBER.";
$lang['txt_intro_voted'] = 						"The following polls are polls that have received your vote.";


// BREADCRUMB (texts that appears when you role over the breadcrumb navigation)
$lang['nav_breadcrumb'] = 						"poll";

?>
